Index: src/v8globals.h |
diff --git a/src/v8globals.h b/src/v8globals.h |
index 1f34d97bc3735979906ccf1e1904f0d9e52abbb2..3e2453edf9ef74423cb01b75986e1a0e5cb5ce0f 100644 |
--- a/src/v8globals.h |
+++ b/src/v8globals.h |
@@ -310,7 +310,10 @@ enum InLoopFlag { |
enum CallFunctionFlags { |
NO_CALL_FUNCTION_FLAGS = 0, |
- RECEIVER_MIGHT_BE_VALUE = 1 << 0 // Receiver might not be a JSObject. |
+ // Receiver might not be a JSObject. |
+ RECEIVER_MIGHT_BE_VALUE = 1 << 0, |
+ // Receiver is a non-value but might be implicit. |
Kevin Millikin (Chromium)
2011/05/18 15:57:23
As it is, these are used as if mutually exclusive,
|
+ NON_VALUE_RECEIVER_MIGHT_BE_IMPLICIT = 1 << 1 |
}; |
@@ -497,6 +500,14 @@ enum SmiCheckType { |
DO_SMI_CHECK |
}; |
+ |
+// Used to specify whether a receiver is implicitly or explicitly |
+// provided to a call. |
+enum ReceiverType { |
Kevin Millikin (Chromium)
2011/05/18 15:57:23
Maybe this is not quite the right name. There is
Mads Ager (chromium)
2011/05/23 16:31:34
I agree. Your suggestion is better. Done.
|
+ EXPLICIT_RECEIVER = 0, |
+ IMPLICIT_RECEIVER |
+}; |
+ |
} } // namespace v8::internal |
#endif // V8_V8GLOBALS_H_ |